@@ -3,7 +3,7 @@ use ckb_jsonrpc_types::{
     BannedAddr, LocalNode, LocalNodeProtocol, NodeAddress, PeerSyncState, RemoteNode,
     RemoteNodeProtocol, SyncState, Timestamp,
 };
-use ckb_network::{extract_peer_id, NetworkController};
+use ckb_network::{extract_peer_id, multiaddr::Multiaddr, NetworkController};
 use ckb_sync::SyncShared;
 use faketime::unix_time_as_millis;
 use jsonrpc_core::Result;
@@ -602,11 +602,11 @@ impl NetRpc for NetRpcImpl {
                         .map(|peer_id| peer_id.to_base58())
                         .unwrap_or_default(),
                     addresses: node_addresses,
-                    connected_duration: peer.connected_time.elapsed().as_secs().into(),
+                    connected_duration: (peer.connected_time.elapsed().as_millis() as u64).into(),
                     last_ping_duration: peer
                         .ping_rtt
                         .map(|duration| (duration.as_millis() as u64).into()),
-                    sync_state: self.sync_shared.state().peers().state.get(&peer_index).map(
+                    sync_state: self.sync_shared.state().peers().state.get(peer_index).map(
                         |state| PeerSyncState {
                             best_known_header_hash: state
                                 .best_known_header
@@ -734,17 +734,20 @@ impl NetRpc for NetRpcImpl {
     }
 
     fn add_node(&self, peer_id: String, address: String) -> Result<()> {
-        self.network_controller.add_node(
-            format!("{}/p2p/{}", address, peer_id)
-                .parse()
-                .expect("invalid address"),
-        );
+        if let Ok(multiaddr) = address.parse::<Multiaddr>() {
+            if extract_peer_id(&multiaddr).is_some() {
+                self.network_controller.add_node(multiaddr)
+            } else if let Ok(addr) = format!("{}/p2p/{}", address, peer_id).parse() {
+                self.network_controller.add_node(addr)
+            }
+        }
         Ok(())
     }
 
     fn remove_node(&self, peer_id: String) -> Result<()> {
-        self.network_controller
-            .remove_node(&peer_id.parse().expect("invalid peer_id"));
+        if let Ok(id) = peer_id.parse() {
+            self.network_controller.remove_node(&id)
+        }
         Ok(())
     }
 
